```
Usage: vcd network external add-subnet [OPTIONS] <name>

Options:
  -g, --gateway <ip>       gateway ip of the subnet  [required]
  -n, --netmask <netmask>  network mask of the subnet  [required]
  -i, --ip-range <ip>      ip range in StartAddress-EndAddress format
                           [required]
  --dns1 <ip>              ip of the primary dns server of the subnet
  --dns2 <ip>              ip of the secondary dns server of the subnet
  --dns-suffix <name>      dns suffix
  -h, --help               Show this message and exit.

```
